/*
Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
Copyright (C) 2005- The University of Notre Dame
This software is distributed under a BSD-style license.
See the file COPYING for details.
*/

#ifndef DEBUG_H
#define DEBUG_H

#include <stdio.h>
#include <unistd.h>
#include <sys/types.h>

#define DEBUG_PORT 9101

#define D_SYSCALL  0x00000001
#define D_CHANNEL  0x00000002
#define D_PROCESS  0x00000004
#define D_NOTICE   0x00000008
#define D_RESOLVE  0x00000010
#define D_LIBCALL  0x00000020
#define D_LOCAL    0x00000040
#define D_DNS      0x00000080
#define D_TCP      0x00000100
#define D_AUTH     0x00000200
#define D_HTTP     0x00001000
#define D_FTP      0x00002000
#define D_NEST     0x00004000
#define D_CHIRP    0x00010000
#define D_DCAP     0x00020000
#define D_RFIO     0x00040000
#define D_GLITE    0x00080000
#define D_MULTI    0x00100000
#define D_PSTREE   0x00200000
#define D_ALLOC    0x00400000
#define D_LFC	   0x00800000
#define D_GFAL	   0x01000000
#define D_SUMMARY  0x02000000
#define D_DEBUG    0x04000000
#define D_RAW      0x08000000
#define D_CACHE    0x10000000
#define D_POLL     0x20000000
#define D_TIME     0x40000000
#define D_PID      0x80000000

#define D_REMOTE   (D_HTTP|D_FTP|D_NEST|D_CHIRP|D_DCAP|D_RFIO|D_LFC|D_GFAL|D_MULTI)
#define D_ALL      0xffffffff

/*
It turns out that many libraries and tools make use of
symbols like "debug" and "fatal".  This causes strange
failures when we link against such codes.  Rather than change
all of our code, we simply insert these defines to
transparently modify the linker namespace we are using.
*/

#define debug                  cctools_debug
#define fatal                  cctools_fatal
#define debug_config           cctools_debug_config
#define debug_config_file      cctools_debug_config_file
#define debug_config_file_size cctools_debug_config_file_size
#define debug_config_host      cctools_debug_config_host
#define debug_config_fatal     cctools_debug_config_fatal
#define debug_config_getpid    cctools_debug_config_getpid
#define debug_flags_set        cctools_debug_flags_set
#define debug_flags_print      cctools_debug_flags_print
#define debug_flags_clear      cctools_debug_flags_clear
#define debug_flags_restore    cctools_debug_flags_restore

void debug( int flags, char *fmt, ... );
void fatal( char *fmt, ... );

void debug_config( char *name );

void debug_config_file( const char *file );
void debug_config_file_size( int size );
int  debug_config_host( const char *host );
void debug_config_fatal( void (*callback) () );
void debug_config_getpid( pid_t (*getpidfunc)() );

int  debug_flags_set( const char *flagname );
void debug_flags_print( FILE *stream );
int  debug_flags_clear();
void debug_flags_restore( int fl );

#endif

